@@ -8,7 +8,7 @@ from .util.Util import UnknownTaskTypeError
 
 class TaskFactoryGenerator:
 	"""Class responsible for parsing input and generating corresponding task factory"""
-	_factories = {
+	_factories: dict = {
 		"117": ActionTask,
 		"112": ImportTask,
 		"116": ExportTask,
@@ -21,7 +21,7 @@ class TaskFactoryGenerator:
 		if action_id in self._factories:
 			self._action_id = action_id
 		else:
-			raise UnknownTaskTypeError(f"Unknown action ID, must be one of {''.join(list(self._factories.keys()))}")
+			raise UnknownTaskTypeError(f"Unknown action ID, must be one of {', '.join(list(self._factories.keys()))}")
 
 	def get_factory(self) -> Union[ActionTask, ExportTask, ImportTask, ProcessTask]:
 		return self._factories[self._action_id]
