@@ -2,7 +2,7 @@
 from .util.AnaplanVersion import AnaplanVersion
 from .util.Util import ResourceNotFoundError, UnknownTaskTypeError, TaskParameterError, InvalidTokenError,\
 	RequestFailedError, AuthenticationFailedError, InvalidAuthenticationError, MappingParameterError,\
-	InvalidUrlError, InvalidTaskTypeError
+	InvalidUrlError, InvalidTaskTypeError, InvalidAuthenticationError
 from .Action import Action
 from .ActionParser import ActionParser
 from .ActionTask import ActionTask
@@ -46,5 +46,5 @@ from .Workspace import Workspace
 from .WorkspaceDetails import WorkspaceDetails
 
 
-__version__ = '0.1.23'
+__version__ = '0.1.26'
 __author__ = 'Jesse Wilson'
